---
name: Bug report
about: Report a bug in `litestar-playwright`
title: "Bug: "
labels: bug
assignees: "hasansezertasan"
---

# Bug Report

## Bug Description

<!--
This issue tracker is a tool to address bugs in litestar-playwright itself.
Please use GitHub Discussions for questions about your own code.

Replace this comment with a clear outline of what the bug is.
-->

## How to Reproduce

<!--
Describe how to replicate the bug.

Please provide a minimal reproducible example that developers can run to investigate the problem.
You can find help for creating such an example [here](https://stackoverflow.com/help/minimal-reproducible-example).

Here is an example of a minimal reproducible example:

```python
...
```

Include the full traceback if there was an exception. For example:

```shell
...
```
-->

## Expected Behavior

<!--
Describe the expected behavior that should have happened but didn't.
-->

## Environment

<!--
You can skip this section if you have provided a minimal reproducible example that includes the
environment information as part of the code snippet (inline metadata).

Otherwise, please complete the following information

Read more about inline metadata:
  - [PEP 723 – Inline script metadata | peps.python.org](https://peps.python.org/pep-0723/)
  - [Inline script metadata - Python Packaging User Guide](https://packaging.python.org/en/latest/specifications/inline-script-metadata/)
-->

- litestar-playwright version: [e.g. 0.1.0]
- litestar version: [e.g. 0.1.0]
- playwright version: [e.g. 0.1.0]
- python version: [e.g. 3.10]
- operating system: [e.g. Windows 10, macOS 12, Ubuntu 20.04]
- browser: [e.g. Chrome, Firefox, Safari]
- browser version: [e.g. 100, 99, 101]

## Additional Context

<!--
Add any other context about the problem here.
-->
